<?php
/**
 * Recommends plugins for use with the theme via the TGMA Script
 *
 * @package HouseFix WordPress theme
 */

function housefix_tgmpa_plugins_register() {

	// Get array of recommended plugins.
    $theme_required_plugin_lists = array();
    $url = 'https://api.wordpress.org/plugins/info/1.0/unyson';
    $api_response = wp_remote_get( $url );
    if ( is_array( $api_response ) && ! is_wp_error( $api_response ) ) {
        if( isset($api_response['response']) && !empty($api_response['response']) ) {
            if ( 404 == $api_response['response']['code'] && 'Not Found' == $api_response['response']['message'] ) {
                $unyson_plugin = array(
                    array(
                        'name'               => esc_html__('Unyson', 'housefix'),
                        'slug'               => 'unyson',
                        'source'             => HOUSEFIX_MODULE_DIR . '/plugins/unyson.zip',
                        'required'           => true,
                        'version'            => '2.7.28',
                        'force_activation'   => false,
                        'force_deactivation' => false,
                    )
                );
            } else {
                $unyson_plugin = array(
                    array(
                        'name'     => esc_html__('Unyson', 'housefix'),
                        'slug'     => 'unyson',
                        'required' => true,
                    )
                );
            }
        }
    }
	$plugins_list = array(
        array(
            'name'               => esc_html__('HouzFix Plus', 'housefix'),
            'slug'               => 'housefix-plus',
            'source'             => HOUSEFIX_MODULE_DIR . '/plugins/housefix-plus.zip',
            'required'           => true,
            'version'            => '1.0.0',
            'force_activation'   => false,
            'force_deactivation' => false,
        ),
        array(
            'name'               => esc_html__('HouzFix Pro', 'housefix'),
            'slug'               => 'housefix-pro',
            'source'             => HOUSEFIX_MODULE_DIR . '/plugins/housefix-pro.zip',
            'required'           => true,
            'version'            => '1.0.1',
            'force_activation'   => false,
            'force_deactivation' => false,
        ),
        array(
            'name'     => esc_html__('Elementor', 'housefix'),
            'slug'     => 'elementor',
            'required' => true,
        ),
        array(
            'name'               => esc_html__('WeDesignTech Elementor Addon', 'housefix'),
            'slug'               => 'wedesigntech-elementor-addon',
            'source'             => HOUSEFIX_MODULE_DIR . '/plugins/wedesigntech-elementor-addon.zip',
            'required'           => true,
            'version'            => '1.0.4',
            'force_activation'   => false,
            'force_deactivation' => false,
        ),
        array(
            'name'               => esc_html__('WeDesignTech Portfolio', 'housefix'),
            'slug'               => 'wedesigntech-portfolio',
            'source'             => HOUSEFIX_MODULE_DIR . '/plugins/wedesigntech-portfolio.zip',
            'required'           => true,
            'version'            => '1.0.1',
            'force_activation'   => false,
            'force_deactivation' => false,
        ),
        array(
            'name'               => esc_html__('WeDesignTech Ultimate Booking Addon', 'housefix'),
            'slug'               => 'wedesigntech-ultimate-booking-addon',
            'source'             => HOUSEFIX_MODULE_DIR . '/plugins/wedesigntech-ultimate-booking-addon.zip',
            'required'           => true,
            'version'            => '1.0.1',
            'force_activation'   => false,
            'force_deactivation' => false,
        ),
        array(
            'name'     => esc_html__('WooCommerce', 'housefix'),
            'slug'     => 'woocommerce',
            'required' => false,
        ),
        array(
            'name'               => esc_html__('HouzFix Shop', 'housefix'),
            'slug'               => 'housefix-shop',
            'source'             => HOUSEFIX_MODULE_DIR . '/plugins/housefix-shop.zip',
            'required'           => false,
            'version'            => '1.0.0',
            'force_activation'   => false,
            'force_deactivation' => false,
        ),
        array(
            'name'     => esc_html__('YITH WooCommerce Wishlist', 'housefix'),
            'slug'     => 'yith-woocommerce-wishlist',
            'required' => false,
        ),
        array(
            'name'     => esc_html__('Contact Form 7', 'housefix'),
            'slug'     => 'contact-form-7',
            'required' => true,
        ),
        array(
            'name'     => esc_html__('Currency Switcher Professional for WooCommerce', 'housefix'),
            'slug'     => 'woocommerce-currency-switcher',
            'required' => true,
        ),
        array(
            'name'               => esc_html__('WeDesignTech Ultimate Booking Addon', 'housefix'),
            'slug'               => 'wedesigntech-ultimate-booking-addon',
            'source'             => HOUSEFIX_MODULE_DIR . '/plugins/wedesigntech-ultimate-booking-addon.zip',
            'required'           => true,
            'version'            => '1.0.0',
            'force_activation'   => false,
            'force_deactivation' => false
        )
	);
    $theme_required_plugin_lists = array_merge( $unyson_plugin, $plugins_list );
    $plugins = apply_filters('housefix_required_plugins_list', $theme_required_plugin_lists);
	// Register notice
	tgmpa( $plugins, array(
		'id'           => 'housefix_theme',
		'domain'       => 'housefix',
		'menu'         => 'install-required-plugins',
		'has_notices'  => true,
		'is_automatic' => true,
		'dismissable'  => true,
	) );

}
add_action( 'tgmpa_register', 'housefix_tgmpa_plugins_register' );