<?php
if ( !class_exists( 'DTCustomerPostType' ) ) {

	class DTCustomerPostType {

		function __construct() {
			add_action ( 'init', array (
				$this,
				'dt_init'
			) );

			add_action ( 'admin_init', array (
				$this,
				'dt_admin_init'
			) );

			add_filter ( 'cs_metabox_options', array(
				$this,
				'dt_customers_cs_metabox_options'
			) );

			add_action( 'admin_menu', array(
				$this,
				'dt_customers_post_submenu'
			) );
		}

		function dt_init() {
			$labels = array(
				'name' => esc_html__('Customers', 'ultimate-booking-pro' ),
				'singular_name' => esc_html__('Customer', 'ultimate-booking-pro' ),
				'menu_name' => esc_html__('Calendar', 'ultimate-booking-pro' ),
				'add_new' => esc_html__('Add Customer', 'ultimate-booking-pro' ),
				'add_new_item' => esc_html__('Add New Customer', 'ultimate-booking-pro' ),
				'edit' => esc_html__('Edit Customer', 'ultimate-booking-pro' ),
				'edit_item' => esc_html__('Edit Customer', 'ultimate-booking-pro' ),
				'new_item' => esc_html__('New Customer', 'ultimate-booking-pro' ),
				'view' => esc_html__('View Customer', 'ultimate-booking-pro' ),
				'view_item' => esc_html__('View Customer', 'ultimate-booking-pro' ),
				'search_items' => esc_html__('Search Customers', 'ultimate-booking-pro' ),
				'not_found' => esc_html__('No Customers found', 'ultimate-booking-pro' ),
				'not_found_in_trash' => esc_html__('No Customers found in Trash', 'ultimate-booking-pro' ),
				'parent_item_colon' => esc_html__('Parent Customer:', 'ultimate-booking-pro' ),
			);

			$args = array(
				'labels' => $labels,
				'hierarchical' => false,
				'description' => esc_html__('This is Custom Post type named as Customers','ultimate-booking-pro'),
				'supports' => array('title'),
				'public' => true,
				'show_ui' => true,
				'show_in_menu' => 'admin.php?page=dt_calendar',
				'show_in_admin_bar' => true,
				'menu_position' => 7,
				'menu_icon' => 'dashicons-clipboard',
			);

			register_post_type('dt_customers', $args );
		}

		function dt_admin_init() {
			add_filter ( "manage_edit-dt_customers_columns", array (
				$this,
				"dt_customers_edit_columns"
			) );

			add_action ( "manage_posts_custom_column", array (
				$this,
				"dt_customers_columns_display"
			), 10, 2 );
		}

		function dt_customers_post_submenu() {
			add_submenu_page( 'dt_calendar', esc_html__('Customers', 'ultimate-booking-pro'), esc_html__('Customers', 'ultimate-booking-pro'), 'manage_options','edit.php?post_type=dt_customers');
		}

		function dt_customers_cs_metabox_options( $options ) {

			$options[]    = array(
			  'id'        => '_info',
			  'title'     => esc_html__('Customer Options', 'ultimate-booking-pro'),
			  'post_type' => 'dt_customers',
			  'context'   => 'normal',
			  'priority'  => 'default',
			  'sections'  => array(

				array(
				  'name'  => 'address_section',
				  'title' => esc_html__('Address', 'ultimate-booking-pro'),
				  'icon'  => 'fa fa-map-pin',

				  'fields' => array(
					array(
					  'id'    => 'firstname',
					  'type'  => 'text',
					  'title' => esc_html__('First Name', 'ultimate-booking-pro'),
					),

					array(
					  'id'    => 'lastname',
					  'type'  => 'text',
					  'title' => esc_html__('Last Name', 'ultimate-booking-pro'),
					),

					array(
					  'id'    => 'address',
					  'type'  => 'text',
					  'title' => esc_html__('Address', 'ultimate-booking-pro'),
					),

					array(
					  'id'      => 'country',
					  'type'    => 'select',
					  'title'   => esc_html__('Country', 'ultimate-booking-pro'),
					  'options' => ultimate_booking_pro_countries_array(),
					  'class'   => 'chosen',
					  'attributes' => array(
						'style' => 'width: 63%;',
					  )
					),

					array(
					  'id'    => 'city',
					  'type'  => 'text',
					  'title' => esc_html__('City', 'ultimate-booking-pro'),
					),

					array(
					  'id'    => 'state',
					  'type'  => 'text',
					  'title' => esc_html__('State', 'ultimate-booking-pro'),
					),

					array(
					  'id'    => 'pincode',
					  'type'  => 'text',
					  'title' => esc_html__('Pin Code', 'ultimate-booking-pro'),
					),

					array(
					  'id'    => 'phone',
					  'type'  => 'text',
					  'title' => esc_html__('Phone', 'ultimate-booking-pro'),
					  'attributes' => array(
						'placeholder' => '022-65265'
					  )
					),

					array(
					  'id'    => 'aboutyourproject',
					  'type'  => 'text',
					  'title' => esc_html__('Notes', 'ultimate-booking-pro'),
					),

					array(
					  'id'    => 'emailid',
					  'type'  => 'text',
					  'title' => esc_html__('Email Id', 'ultimate-booking-pro'),
					  'attributes' => array(
						'placeholder' => 'testmail@domain.com',
					  )
					),

				    array(
					  'id'      => 'customer_id',
					  'type'    => 'select',
					  'title'   => esc_html__('Customer', 'ultimate-booking-pro'),
					  'options' => ultimate_booking_pro_get_wp_users(),
					  'class'   => 'chosen',
					  'default_option' => esc_html__('Guest', 'ultimate-booking-pro'),
					  'attributes' => array(
						'style' => 'width: 60%;',
					  )
				    ),

				  ), // end: fields
				), // end: a section

			  ),
			);

			return $options;
		}

		function dt_customers_edit_columns($columns) {

			$newcolumns = array (
				"cb"         => "<input type=\"checkbox\" />",
				"title"      => esc_html__("Title", 'ultimate-booking-pro'),
				"address" 	 => esc_html__("Address", 'ultimate-booking-pro'),
				"user"     	 => esc_html__("User", 'ultimate-booking-pro'),
			);

			$columns = array_merge ( $newcolumns, $columns );
			unset($columns['date']);
			return $columns;
		}

		function dt_customers_columns_display($columns, $id) {
			global $post;

			$customer_settings = get_post_meta ( $post->ID, '_info', TRUE );
			$customer_settings = is_array ( $customer_settings ) ? $customer_settings : array ();

			switch ($columns) {

				case "address" :
					if( array_key_exists("address", $customer_settings) && $customer_settings['address'] != '' ) {
						echo "{$customer_settings['address']}";
					}
					if( array_key_exists("city", $customer_settings) && $customer_settings['city'] != '' ) {
						echo ', '.$customer_settings['city'];
					}
					if( array_key_exists("state", $customer_settings) && $customer_settings['state'] != '' ) {
						echo ', '.$customer_settings['state'];
					}
					if( array_key_exists("country", $customer_settings) && $customer_settings['country'] != '' ) {
						echo "<br>".$customer_settings['country'];
					}
					if( array_key_exists("pincode", $customer_settings) && $customer_settings['pincode'] != '' ) {
						echo ' - '.$customer_settings['pincode'];
					}
				break;

				case "user" :
					if( array_key_exists("customer_id", $customer_settings) && $customer_settings['customer_id'] != '' ) {
						$user_id     = $customer_settings['customer_id'];
						$user_info   = get_userdata($user_id);

						echo '<a href="'.get_edit_user_link( $user_id ).'" title="'.esc_attr__('Edit Profile', 'ultimate-booking-pro').'">'.$user_info->user_login.' (#'.$user_id.' - '.$user_info->user_email.')';
					}
				break;
			}
		}
	}
}