<?php
if ( !class_exists( 'DTPaymentPostType' ) ) {

	class DTPaymentPostType {

		function __construct() {
			add_action ( 'init', array (
				$this,
				'dt_init'
			) );

			add_action ( 'admin_init', array (
				$this,
				'dt_admin_init'
			) );

			add_filter ( "cs_metabox_options", array(
				$this,
				"dt_payments_cs_metabox_options"
			) );

			add_action( 'admin_menu', array(
				$this,
				'dt_payments_post_submenu'
			) );
		}

		function dt_init() {
			$labels = array(
				'name' => esc_html__('Payments', 'ultimate-booking-pro' ),
				'singular_name' => esc_html__('Payment', 'ultimate-booking-pro' ),
				'menu_name' => esc_html__('Calendar', 'ultimate-booking-pro' ),
				'add_new' => esc_html__('Add Payment', 'ultimate-booking-pro' ),
				'add_new_item' => esc_html__('Add New Payment', 'ultimate-booking-pro' ),
				'edit' => esc_html__('Edit Payment', 'ultimate-booking-pro' ),
				'edit_item' => esc_html__('Edit Payment', 'ultimate-booking-pro' ),
				'new_item' => esc_html__('New Payment', 'ultimate-booking-pro' ),
				'view' => esc_html__('View Payment', 'ultimate-booking-pro' ),
				'view_item' => esc_html__('View Payment', 'ultimate-booking-pro' ),
				'search_items' => esc_html__('Search Payments', 'ultimate-booking-pro' ),
				'not_found' => esc_html__('No Payments found', 'ultimate-booking-pro' ),
				'not_found_in_trash' => esc_html__('No Payments found in Trash', 'ultimate-booking-pro' ),
				'parent_item_colon' => esc_html__('Parent Payment:', 'ultimate-booking-pro' ),
			);

			$args = array(
				'labels' => $labels,
				'hierarchical' => false,
				'description' => esc_html__('This is Payment Post type named as Payments','ultimate-booking-pro'),
				'supports' => array('title'),
				'public' => true,
				'show_ui' => true,
				'show_in_menu' => 'admin.php?page=dt_calendar',
				'show_in_admin_bar' => true,
				'menu_position' => 7,
				'menu_icon' => 'dashicons-clipboard',
			);

			register_post_type('dt_payments', $args );
		}

		function dt_admin_init() {
			add_filter ( "manage_edit-dt_payments_columns", array (
				$this,
				"dt_payments_edit_columns"
			) );

			add_action ( "manage_posts_custom_column", array (
				$this,
				"dt_payments_columns_display"
			), 10, 2 );
		}

		function dt_payments_post_submenu() {
			add_submenu_page( 'dt_calendar', esc_html__('Payments', 'ultimate-booking-pro'), esc_html__('Payments', 'ultimate-booking-pro'), 'manage_options','edit.php?post_type=dt_payments');
		}

		function dt_payments_cs_metabox_options( $options ) {

			$options[]    = array(
			  'id'        => '_info',
			  'title'     => esc_html__('Payment Options', 'ultimate-booking-pro'),
			  'post_type' => 'dt_payments',
			  'context'   => 'normal',
			  'priority'  => 'default',
			  'sections'  => array(
				array(
				  'name'   => 'orders_section',
				  'title'  => esc_html__('Orders', 'ultimate-booking-pro'),
				  'icon'   => 'fa fa-gift',

				  'fields' => array(
					array(
					  'id'    => 'order_date',
					  'type'  => 'text',
					  'title' => esc_html__('Order Date', 'ultimate-booking-pro'),
					),
					array(
					  'id'    => 'order_type',
					  'type'  => 'text',
					  'title' => esc_html__('Order Type', 'ultimate-booking-pro'),
					),
					array(
					  'id'    => 'order_service',
					  'type'  => 'text',
					  'title' => esc_html__('Service', 'ultimate-booking-pro'),
					),
					array(
					  'id'    => 'order_status',
					  'type'  => 'text',
					  'title' => esc_html__('Order Status', 'ultimate-booking-pro'),
					),
					array(
					  'id'    => 'order_transid',
					  'type'  => 'text',
					  'title' => esc_html__('Transaction ID', 'ultimate-booking-pro'),
					),
					array(
					  'id'    => 'order_amount',
					  'type'  => 'text',
					  'title' => esc_html__('Amount', 'ultimate-booking-pro'),
					),
				  ), // end: fields
				), // end: a section

				array(
				  'name'  => 'address_section',
				  'title' => esc_html__('Address', 'ultimate-booking-pro'),
				  'icon'  => 'fa fa-map-pin',

				  'fields' => array(
					array(
					  'id'    => 'firstname',
					  'type'  => 'text',
					  'title' => esc_html__('First Name', 'ultimate-booking-pro'),
					),

					array(
					  'id'    => 'lastname',
					  'type'  => 'text',
					  'title' => esc_html__('Last Name', 'ultimate-booking-pro'),
					),

					array(
					  'id'    => 'address',
					  'type'  => 'text',
					  'title' => esc_html__('Address', 'ultimate-booking-pro'),
					),

					array(
					  'id'      => 'country',
					  'type'    => 'select',
					  'title'   => esc_html__('Country', 'ultimate-booking-pro'),
					  'options' => ultimate_booking_pro_countries_array(),
					  'class'   => 'chosen',
					  'attributes' => array(
						'style' => 'width: 63%;',
					  )
					),

					array(
					  'id'    => 'city',
					  'type'  => 'text',
					  'title' => esc_html__('City', 'ultimate-booking-pro'),
					),

					array(
					  'id'    => 'state',
					  'type'  => 'text',
					  'title' => esc_html__('State', 'ultimate-booking-pro'),
					),

					array(
					  'id'    => 'pincode',
					  'type'  => 'text',
					  'title' => esc_html__('Pin Code', 'ultimate-booking-pro'),
					),

					array(
					  'id'    => 'phone',
					  'type'  => 'text',
					  'title' => esc_html__('Phone', 'ultimate-booking-pro'),
					  'attributes' => array(
						'placeholder' => '022-65265'
					  )
					),

					array(
					  'id'    => 'aboutyourproject',
					  'type'  => 'text',
					  'title' => esc_html__('Notes', 'ultimate-booking-pro'),
					),

					array(
					  'id'    => 'emailid',
					  'type'  => 'text',
					  'title' => esc_html__('Email Id', 'ultimate-booking-pro'),
					  'attributes' => array(
						'placeholder' => 'testmail@domain.com',
					  )
					),

				    array(
					  'id'      => 'customer_id',
					  'type'    => 'select',
					  'title'   => esc_html__('Customer', 'ultimate-booking-pro'),
					  'options' => 'posts',
					  'query_args' => array(
						'post_type'      => 'dt_customers',
						'orderby'        => 'ID',
						'order'          => 'ASC',
						'posts_per_page' => -1,
					  ),
					  'class'   => 'chosen',
					  'default_option' => esc_html__('Guest', 'ultimate-booking-pro'),
					  'attributes' => array(
						'style' => 'width: 60%;',
					  )
				    ),

				  ), // end: fields
				), // end: a section

			  ),
			);

			return $options;
		}

		function dt_payments_edit_columns($columns) {

			$newcolumns = array (
				"cb"         => "<input type=\"checkbox\" />",
				"title"      => esc_html__("Title", 'ultimate-booking-pro'),
				"order_date" => esc_html__("Order Date", 'ultimate-booking-pro'),
				"type"       => esc_html__("Order Type", 'ultimate-booking-pro'),
				"cost"       => esc_html__("Cost", 'ultimate-booking-pro'),
				"status"     => esc_html__("Status", 'ultimate-booking-pro'),
			);

			$columns = array_merge ( $newcolumns, $columns );
			unset($columns['date']);
			return $columns;
		}

		function dt_payments_columns_display($columns, $id) {
			global $post;

			$payment_settings = get_post_meta ( $post->ID, '_info', TRUE );
			$payment_settings = is_array ( $payment_settings ) ? $payment_settings : array ();

			switch ($columns) {

				case "order_date" :
					if( array_key_exists("order_date", $payment_settings) && $payment_settings['order_date'] != '' ) {
						echo "{$payment_settings['order_date']}";
					}
				break;

				case "type" :
					if( array_key_exists("order_type", $payment_settings) && $payment_settings['order_type'] != '' ) {
						echo "{$payment_settings['order_type']}";
					}
				break;

				case "cost" :
					if( array_key_exists("order_amount", $payment_settings) && $payment_settings['order_amount'] != '' ) {
						echo "{$payment_settings['order_amount']}";
					}
				break;

				case "status" :
					if( array_key_exists("order_status", $payment_settings) && $payment_settings['order_status'] != '' ) {
						echo "{$payment_settings['order_status']}";
					} else {
						echo esc_html__('Completed', 'ultimate-booking-pro');
					}
				break;
			}
		}
	}
}