<?php
use UltimateBookingPro\Widgets\UltimateBookingProWidgetBase;
use Elementor\Controls_Manager;
use Elementor\Utils;

class Elementor_Staff_Item extends UltimateBookingProWidgetBase {

    public function get_name() {
        return 'dt-staff-item';
    }

    public function get_title() {
        return $this->get_singular_name();
    }

    public function get_icon() {
		return 'eicon-apps';
	}

    public function get_singular_name() {

        $singular_name = esc_html__('Staff', 'ultimate-booking-pro');

        if( function_exists( 'ultimate_booking_pro_cs_get_option' ) ) :
            $singular_name = ultimate_booking_pro_cs_get_option( 'singular-staff-text', esc_html__('Staff', 'ultimate-booking-pro') );
        endif;

        return $singular_name;
    }

    protected function register_controls() {

        $this->start_controls_section( 'dt_section_general', array(
            'label' => esc_html__( 'General', 'ultimate-booking-pro'),
        ) );

            $this->add_control( 'staff_id', array(
                'label' => esc_html__( 'Enter Staff ID', 'ultimate-booking-pro' ),
                'type' => Controls_Manager::SELECT2,
                'label_block' => true,
                'multiple' => false,
                'options' => $this->dt_get_post_ids('dt_staff')
            ));

            $this->add_control( 'type', array(
                'label' => esc_html__( 'Type', 'ultimate-booking-pro' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'type1',
                'options' => array(
                    'type1' => esc_html__( 'Type - I', 'ultimate-booking-pro' ),
                    'type2' => esc_html__( 'Type - II', 'ultimate-booking-pro' ),
                )
            ));

            $this->add_control( 'show_button', array(
                'label' => esc_html__( 'Show button?', 'ultimate-booking-pro' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'no',
                'options' => array(
                    'yes' => esc_html__( 'Yes', 'ultimate-booking-pro' ),
                    'no' => esc_html__( 'No', 'ultimate-booking-pro' ),
                )
            ));

            $this->add_control( 'button_text', array(
                'label' => esc_html__( 'Button Text', 'ultimate-booking-pro' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Book an appointment', 'ultimate-booking-pro'),
            ));

        $this->end_controls_section();
    }

    protected function render() {

        $settings = $this->get_settings();
        extract( $settings );

        $out = '';

        #Performing query...
        $args = array('post_type' => 'dt_staff', 'p' => $staff_id );

        $the_query = new WP_Query($args);
        if($the_query->have_posts()):

            while($the_query->have_posts()): $the_query->the_post();
                $PID = $staff_id;

                #Meta...
                $staff_settings = get_post_meta($PID, '_custom_settings', true);
                $staff_settings = is_array ( $staff_settings ) ? $staff_settings : array ();

                $out .= '<div class="dt-sc-staff-item '.$type.'">';
                    $out .= '<div class="image">';
                            if(has_post_thumbnail()):
                                $attr = array('title' => get_the_title(), 'alt' => get_the_title());
                                $img_size = 'full';

                                if( $type == 'type2' ) {
                                    $img_size = 'dt-bm-staff-type2';
                                }
                                $out .= get_the_post_thumbnail($PID, $img_size, $attr);
                            else:
                                $img_pros = '600x692';

                                if( $type == 'type2' ) {
                                    $img_pros = '205x205';
                                }
                                $out .= '<img src="https://place-hold.it/'.$img_pros.'&text='.get_the_title().'" alt="'.get_the_title().'" />';
                            endif;

                            if( $show_button == 'yes' ):
                                $out .= '<div class="dt-sc-staff-overlay">';
                                    $out .= '<a class="dt-sc-button white medium bordered" href="'.get_permalink().'" title="'.get_the_title().'">'.esc_html($button_text).'</a>';
                                $out .= '</div>';
                            endif;
                    $out .= '</div>';

                    $out .= '<div class="staff-details">';
                        $out .= '<h3><a href="'.get_permalink().'" title="'.get_the_title().'">'.get_the_title().'</a></h3>';
                        if( array_key_exists('staff-role', $staff_settings) ):
                            $out .= '<h6>'.$staff_settings['staff-role'].'</h6>';
                        endif;

                        if( array_key_exists('appointment_fs1', $staff_settings) && array_key_exists('appointment_fs5', $staff_settings) ):
                            $out .= '<p>'.esc_html__('Monday to Friday : ', 'ultimate-booking-pro').$staff_settings['appointment_fs1']['ultimate_booking_pro_monday_start'].' - '.$staff_settings['appointment_fs5']['ultimate_booking_pro_friday_end'].esc_html__(' hrs', 'ultimate-booking-pro');
                        endif;
                    $out .= '</div>';
                $out .= '</div>';
            endwhile;

            wp_reset_postdata();
        else:
            $out .= '<h2>'.esc_html__("Nothing Found.", "ultimate-booking-pro").'</h2>';
            $out .= '<p>'.esc_html__("Apologies, but no results were found for the requested archive.", "ultimate-booking-pro").'</p>';
        endif;

        echo "{$out}";
    }

    protected function _content_template() {
    }
}